# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.apiactivity.classes.types.api_activity import (
    ApiActivity as ocsf_v_1_3_0_apiactivity_classes_types_api_activity_ApiActivity,
)

ApiActivity = ocsf_v_1_3_0_apiactivity_classes_types_api_activity_ApiActivity
