# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .sumo_logic_collection_url import SumoLogicCollectionUrl
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SinkSumoLogic(UncheckedBaseModel):
    """
    Configuration for Sumo Logic as a Sink provider. Allows sending data to Sumo Logic using a collection URL.

    [Configuration guide](https://docs.synqly.com/guides/provider-configuration/sumo-logic-sink-setup)
    """

    collection_url: SumoLogicCollectionUrl = pydantic.Field()
    """
    Sumo Logic Collection URL for writing events.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
