# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.authentication.classes.types.authentication import (
    Authentication as ocsf_v_1_3_0_authentication_classes_types_authentication_Authentication,
)

Authentication = ocsf_v_1_3_0_authentication_classes_types_authentication_Authentication
