# This file was auto-generated by Fern from our API Definition.

from ...engine.types.api_response import ApiResponse
from .investigation import Investigation
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class GetInvestigationResponse(ApiResponse):
    result: Investigation = pydantic.Field()
    """
    The investigation object
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
