# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.vulnerabilityfinding.classes.types.vulnerability_finding import (
    VulnerabilityFinding as ocsf_v_1_3_0_vulnerabilityfinding_classes_types_vulnerability_finding_VulnerabilityFinding,
)

VulnerabilityFinding = ocsf_v_1_3_0_vulnerabilityfinding_classes_types_vulnerability_finding_VulnerabilityFinding
