# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .azure_blob_credential import AzureBlobCredential
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class SinkAzureBlob(UncheckedBaseModel):
    """
    Configuration for Azure Blob Storage as a Sink provider. Events are written directly to an Azure Blob Storage container in compressed JSON format.
    """

    bucket: str = pydantic.Field()
    """
    Name of the Azure Blob Storage container
    """

    credential: AzureBlobCredential = pydantic.Field()
    """
    Azure token with write access to the configured blob container.
    """

    path: str = pydantic.Field()
    """
    Files will be written under this path.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
