# This file was auto-generated by Fern from our API Definition.

from ....v_1_5_0.applicationsecurityposturefinding.classes.types.application_security_posture_finding import (
    ApplicationSecurityPostureFinding as ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_application_security_posture_finding_ApplicationSecurityPostureFinding,
)

ApplicationSecurityPostureFinding = ocsf_v_1_5_0_applicationsecurityposturefinding_classes_types_application_security_posture_finding_ApplicationSecurityPostureFinding
