# This file was auto-generated by Fern from our API Definition.

from ...engine.types.api_query_response import ApiQueryResponse
import typing
from .project import Project
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ListProjectsResponse(ApiQueryResponse):
    result: typing.List[Project]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
