# This file was auto-generated by Fern from our API Definition.

from ...management.types.mapping_chain import MappingChain
import typing
from ...providers_generated.types.provider_config_id import ProviderConfigId
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class MappingChainTemplate(MappingChain):
    providers: typing.List[ProviderConfigId] = pydantic.Field()
    """
    A list of provider ID strings that this mapping applies to. Mapping templates must have at least one provider.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
