# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.webresourceaccessactivity.classes.types.web_resource_access_activity import (
    WebResourceAccessActivity as ocsf_v_1_3_0_webresourceaccessactivity_classes_types_web_resource_access_activity_WebResourceAccessActivity,
)

WebResourceAccessActivity = ocsf_v_1_3_0_webresourceaccessactivity_classes_types_web_resource_access_activity_WebResourceAccessActivity
