# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from ...common.types.id import Id
from .actor import Actor
from ...engine.types.object import Object
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class EscalationPolicyRule(UncheckedBaseModel):
    """
    The escalation policy rule object describes a rule for an escalation policy. It contains an optional id for the rule, a delay in seconds before the next actor is notified, and a list of actors.
    """

    id: typing.Optional[Id] = None
    delay_seconds: int
    actors: typing.List[Actor]
    unmapped: typing.Optional[Object] = pydantic.Field(default=None)
    """
    The attributes that are not mapped to the comment schema. The names and values of those attributes are specific to the provider.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
