# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PatchOp(str, enum.Enum):
    ADD = "add"
    COPY = "copy"
    MOVE = "move"
    REMOVE = "remove"
    REPLACE = "replace"
    TEST = "test"
    _UNKNOWN = "__PATCHOP_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PatchOp":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        add: typing.Callable[[], T_Result],
        copy: typing.Callable[[], T_Result],
        move: typing.Callable[[], T_Result],
        remove: typing.Callable[[], T_Result],
        replace: typing.Callable[[], T_Result],
        test: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PatchOp.ADD:
            return add()
        if self is PatchOp.COPY:
            return copy()
        if self is PatchOp.MOVE:
            return move()
        if self is PatchOp.REMOVE:
            return remove()
        if self is PatchOp.REPLACE:
            return replace()
        if self is PatchOp.TEST:
            return test()
        return _unknown_member(self._value_)
