# This file was auto-generated by Fern from our API Definition.

from ....core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from ....core.pydantic_utilities import IS_PYDANTIC_V2


class MarkingDefinition(UncheckedBaseModel):
    type: str = pydantic.Field()
    """
    The type property identifies the type of object. The value of this property MUST be marking_definition.
    """

    name: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
