# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.inventoryinfo.classes.types.inventory_info import (
    InventoryInfo as ocsf_v_1_3_0_inventoryinfo_classes_types_inventory_info_InventoryInfo,
)

InventoryInfo = ocsf_v_1_3_0_inventoryinfo_classes_types_inventory_info_InventoryInfo
