# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ListProviderCapabilitiesExpandOptions(str, enum.Enum):
    CONNECTOR = "connector"
    OPERATIONS = "operations"
    PROVIDER_CONFIG = "provider_config"
    _UNKNOWN = "__LISTPROVIDERCAPABILITIESEXPANDOPTIONS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ListProviderCapabilitiesExpandOptions":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        connector: typing.Callable[[], T_Result],
        operations: typing.Callable[[], T_Result],
        provider_config: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ListProviderCapabilitiesExpandOptions.CONNECTOR:
            return connector()
        if self is ListProviderCapabilitiesExpandOptions.OPERATIONS:
            return operations()
        if self is ListProviderCapabilitiesExpandOptions.PROVIDER_CONFIG:
            return provider_config()
        return _unknown_member(self._value_)
