# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
from .operation_frequency_periodic import OperationFrequencyPeriodic
import typing
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class OperationFrequency_Periodic(UncheckedBaseModel):
    value: OperationFrequencyPeriodic
    type: typing.Literal["periodic"] = "periodic"

    class Config:
        smart_union = True


OperationFrequency = typing_extensions.Annotated[
    OperationFrequency_Periodic, UnionMetadata(discriminant="type")
]
