# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .permission_set_actions import PermissionSetActions
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class PermissionSetPermissions(UncheckedBaseModel):
    """
    Permissions for the permissionset API
    """

    actions: typing.List[PermissionSetActions]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
