# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.accountchange.classes.types.account_change import (
    AccountChange as ocsf_v_1_3_0_accountchange_classes_types_account_change_AccountChange,
)

AccountChange = ocsf_v_1_3_0_accountchange_classes_types_account_change_AccountChange
