# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
from ...credentials.types.secret_credential_id import SecretCredentialId
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class SlackWebhookCredential_Secret(UncheckedBaseModel):
    type: typing.Literal["secret"] = "secret"
    secret: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


class SlackWebhookCredential_SecretId(UncheckedBaseModel):
    value: SecretCredentialId
    type: typing.Literal["secret_id"] = "secret_id"

    class Config:
        smart_union = True


SlackWebhookCredential = typing_extensions.Annotated[
    typing.Union[SlackWebhookCredential_Secret, SlackWebhookCredential_SecretId],
    UnionMetadata(discriminant="type"),
]
