# This file was auto-generated by Fern from our API Definition.

from ......core.unchecked_base_model import UncheckedBaseModel
import pydantic
from ......core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class San(UncheckedBaseModel):
    """
    The Subject Alternative name (SAN) object describes a SAN secured by a digital certificate
    """

    name: str = pydantic.Field()
    """
    Name of SAN (e.g. The actual IP Address or domain.)
    """

    type: str = pydantic.Field()
    """
    Type descriptor of SAN (e.g. IP Address/domain/etc.)
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
