# This file was auto-generated by Fern from our API Definition.

from ....core.unchecked_base_model import UncheckedBaseModel
import pydantic
from ....core.pydantic_utilities import IS_PYDANTIC_V2
import typing


class KillChainPhase(UncheckedBaseModel):
    kill_chain_name: str = pydantic.Field()
    """
    The kill_chain_name property specifies the name of the kill chain to which the phase belongs.
    """

    phase_name: str = pydantic.Field()
    """
    The phase_name property specifies the name of the phase within the kill chain.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
