# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.scheduledjobactivity.classes.types.scheduled_job_activity import (
    ScheduledJobActivity as ocsf_v_1_3_0_scheduledjobactivity_classes_types_scheduled_job_activity_ScheduledJobActivity,
)

ScheduledJobActivity = ocsf_v_1_3_0_scheduledjobactivity_classes_types_scheduled_job_activity_ScheduledJobActivity
