# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.fileactivity.classes.types.file_activity import (
    FileActivity as ocsf_v_1_3_0_fileactivity_classes_types_file_activity_FileActivity,
)

FileActivity = ocsf_v_1_3_0_fileactivity_classes_types_file_activity_FileActivity
