# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .crowd_strike_credential import CrowdStrikeCredential
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class CloudSecurityCrowdStrike(UncheckedBaseModel):
    """
    Configuration for the CrowdStrike Cloud Security Provider
    """

    credential: CrowdStrikeCredential
    url: typing.Optional[str] = pydantic.Field(default=None)
    """
    The root domain where your CrowdStrike Falcon tenant is located.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
