# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .meta_stats import MetaStats
import pydantic
from .meta_api import MetaApi
from .meta_mapping import MetaMapping
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class MetaResponse(UncheckedBaseModel):
    stats: typing.Optional[MetaStats] = pydantic.Field(default=None)
    """
    Statistics about items contained in the response.
    """

    api: typing.Optional[MetaApi] = pydantic.Field(default=None)
    """
    Information about backing API requests made to fulfill the response.
    """

    mapping: typing.Optional[MetaMapping] = pydantic.Field(default=None)
    """
    Information about mappings applied during transformation.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
