# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import pydantic
import typing
from .order_direction import OrderDirection
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProviderOrder(UncheckedBaseModel):
    name: str = pydantic.Field()
    """
    Name of the field to order by.
    """

    directions: typing.List[OrderDirection] = pydantic.Field()
    """
    List of possible directions to order by.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
