# This file was auto-generated by Fern from our API Definition.

from ...ocsf.latest.events.types.application_security_posture_finding import (
    ApplicationSecurityPostureFinding,
)

AppSecPostureFinding = ApplicationSecurityPostureFinding
