# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AuthActions(str, enum.Enum):
    LOGON = "logon"
    CHANGE_PASSWORD = "change_password"
    LOGOFF = "logoff"
    ALL = "*"
    _UNKNOWN = "__AUTHACTIONS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "AuthActions":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        logon: typing.Callable[[], T_Result],
        change_password: typing.Callable[[], T_Result],
        logoff: typing.Callable[[], T_Result],
        all_: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is AuthActions.LOGON:
            return logon()
        if self is AuthActions.CHANGE_PASSWORD:
            return change_password()
        if self is AuthActions.LOGOFF:
            return logoff()
        if self is AuthActions.ALL:
            return all_()
        return _unknown_member(self._value_)
