# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.securityfinding.classes.types.security_finding import (
    SecurityFinding as ocsf_v_1_3_0_securityfinding_classes_types_security_finding_SecurityFinding,
)

SecurityFinding = (
    ocsf_v_1_3_0_securityfinding_classes_types_security_finding_SecurityFinding
)
