# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import datetime as dt
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class ProviderSpecificFindingState_Nucleus(UncheckedBaseModel):
    type: typing.Literal["nucleus"] = "nucleus"
    due_date: typing.Optional[dt.datetime] = None
    comment: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow


ProviderSpecificFindingState = typing_extensions.Annotated[
    ProviderSpecificFindingState_Nucleus, UnionMetadata(discriminant="type")
]
