# This file was auto-generated by Fern from our API Definition.

from ....v_1_6_0.emailactivity.classes.types.email_activity import (
    EmailActivity as ocsf_v_1_6_0_emailactivity_classes_types_email_activity_EmailActivity,
)

EmailActivity = ocsf_v_1_6_0_emailactivity_classes_types_email_activity_EmailActivity
