# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import datetime as dt
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class NucleusFindingState(UncheckedBaseModel):
    due_date: typing.Optional[dt.datetime] = pydantic.Field(default=None)
    """
    Due date for the finding.
    """

    comment: typing.Optional[str] = pydantic.Field(default=None)
    """
    Comment to add to the finding.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
