# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from ...member_base.types.member import Member
from .organization import Organization
from ...token_base.types.token_pair import TokenPair
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class CreateOrganizationResponseResult(UncheckedBaseModel):
    member: typing.Optional[Member] = None
    organization: Organization
    token: TokenPair

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
