# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class OrderDirection(str, enum.Enum):
    ASCENDING = "asc"
    """
    Order in ascending order.
    """

    DESCENDING = "desc"
    """
    Order in descending order.
    """

    _UNKNOWN = "__ORDERDIRECTION_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "OrderDirection":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        ascending: typing.Callable[[], T_Result],
        descending: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is OrderDirection.ASCENDING:
            return ascending()
        if self is OrderDirection.DESCENDING:
            return descending()
        return _unknown_member(self._value_)
