# This file was auto-generated by Fern from our API Definition.

from .provider_capabilities_base import ProviderCapabilitiesBase
import typing
from .connector_or_id import ConnectorOrId
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ProviderCapabilities(ProviderCapabilitiesBase):
    connector: typing.Optional[ConnectorOrId] = pydantic.Field(default=None)
    """
    Id of the Connector that the Provider implements – or, if
    `expand=connector` is set – the details of the Connector. NOTE:
    The current default behavior is to return the ID of the
    Connector. This field will soon only be populated when
    `expand=connector` is set in the APIs that support it. It is
    recommended you use `connector_id` for a stable reference to the
    Connector ID. This field will soon only be populated when
    `expand=connector` is set in the APIs that support it.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
