# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.compliancefinding.classes.types.compliance_finding import (
    ComplianceFinding as ocsf_v_1_3_0_compliancefinding_classes_types_compliance_finding_ComplianceFinding,
)

ComplianceFinding = (
    ocsf_v_1_3_0_compliancefinding_classes_types_compliance_finding_ComplianceFinding
)
