# This file was auto-generated by Fern from our API Definition.

from ....v_1_5_0.applicationsecurityposturefinding.objects.types.application import (
    Application,
)

Ocsf150Application = Application
