# This file was auto-generated by Fern from our API Definition.

from ...engine.types.api_query_response import ApiQueryResponse
from ...engine.types.api_has_status import ApiHasStatus
import typing
from .log_provider import LogProvider
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class QueryLogProvidersResponse(ApiQueryResponse, ApiHasStatus):
    result: typing.List[LogProvider] = pydantic.Field()
    """
    List of available metadata.log_provider values available for querying events
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
