# This file was auto-generated by Fern from our API Definition.

from ....v_1_6_0.httpactivity.classes.types.http_activity import (
    HttpActivity as ocsf_v_1_6_0_httpactivity_classes_types_http_activity_HttpActivity,
)

HttpActivity = ocsf_v_1_6_0_httpactivity_classes_types_http_activity_HttpActivity
