# This file was auto-generated by Fern from our API Definition.

from .integration_ticket_when import IntegrationTicketWhen
from .ticketing_webhook_response import TicketingWebhookResponse

__all__ = ["IntegrationTicketWhen", "TicketingWebhookResponse"]
