# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .assets_service_now_dataset import AssetsServiceNowDataset
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import typing
import pydantic


class AssetsServiceNowMock(UncheckedBaseModel):
    """
    Configuration for a mocked ServiceNow as an Assets Provider
    """

    dataset: AssetsServiceNowDataset

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
