# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class BuiltinRoles(str, enum.Enum):
    ROOT_ADMINISTRATOR = "root_administrator"
    ADMINISTRATOR = "administrator"
    VIEWER = "viewer"
    MEMBER = "member"
    _UNKNOWN = "__BUILTINROLES_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "BuiltinRoles":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        root_administrator: typing.Callable[[], T_Result],
        administrator: typing.Callable[[], T_Result],
        viewer: typing.Callable[[], T_Result],
        member: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is BuiltinRoles.ROOT_ADMINISTRATOR:
            return root_administrator()
        if self is BuiltinRoles.ADMINISTRATOR:
            return administrator()
        if self is BuiltinRoles.VIEWER:
            return viewer()
        if self is BuiltinRoles.MEMBER:
            return member()
        return _unknown_member(self._value_)
