# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import datetime as dt
import pydantic
import typing
from .timeseries_result import TimeseriesResult
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class GetStatusTimeseriesResult(UncheckedBaseModel):
    """
    Status timeseries object
    """

    start_time: dt.datetime = pydantic.Field()
    """
    start time
    """

    end_time: dt.datetime = pydantic.Field()
    """
    end time
    """

    interval: str = pydantic.Field()
    """
    interval duration
    """

    series: typing.List[TimeseriesResult]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
