# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from ...common.types.id import Id
import typing
from ...engine.types.object import Object
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class Agent(UncheckedBaseModel):
    """
    An agent is a human that can be notified when certain conditions are met
    """

    uid: Id
    full_name: str
    email_addr: typing.Optional[str] = None
    phone_number: typing.Optional[str] = None
    time_zone: typing.Optional[str] = None
    job_title: typing.Optional[str] = None
    unmapped: typing.Optional[Object] = pydantic.Field(default=None)
    """
    The attributes that are not mapped to the comment schema. The names and values of those attributes are specific to the provider.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
