# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class OperationInput(UncheckedBaseModel):
    filters: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Limit the number of results returned by the operation. If not specified, the operation will return all results.
    """

    limit: typing.Optional[int] = pydantic.Field(default=None)
    """
    Limit query results by these filters.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
