# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class ClarotyApiurl(str, enum.Enum):
    CLAROTY_API_URL_US = "https://api.claroty.com"
    CLAROTY_API_URL_EU = "https://eu.api.claroty.com"
    CLAROTY_API_URL_CA = "https://ca.api.claroty.com"
    CLAROTY_API_URL_AU = "https://au.api.claroty.com"
    CLAROTY_API_URL_DEMO = "https://demo-api.claroty.com"
    _UNKNOWN = "__CLAROTYAPIURL_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "ClarotyApiurl":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        claroty_api_url_us: typing.Callable[[], T_Result],
        claroty_api_url_eu: typing.Callable[[], T_Result],
        claroty_api_url_ca: typing.Callable[[], T_Result],
        claroty_api_url_au: typing.Callable[[], T_Result],
        claroty_api_url_demo: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is ClarotyApiurl.CLAROTY_API_URL_US:
            return claroty_api_url_us()
        if self is ClarotyApiurl.CLAROTY_API_URL_EU:
            return claroty_api_url_eu()
        if self is ClarotyApiurl.CLAROTY_API_URL_CA:
            return claroty_api_url_ca()
        if self is ClarotyApiurl.CLAROTY_API_URL_AU:
            return claroty_api_url_au()
        if self is ClarotyApiurl.CLAROTY_API_URL_DEMO:
            return claroty_api_url_demo()
        return _unknown_member(self._value_)
