# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class PingOneAuthUrl(str, enum.Enum):
    PINGONE_AUTH_URL_US = "https://auth.pingone.com"
    PINGONE_AUTH_URL_CA = "https://auth.pingone.ca"
    PINGONE_AUTH_URL_EU = "https://auth.pingone.eu"
    PINGONE_AUTH_URL_AU = "https://auth.pingone.com.au"
    PINGONE_AUTH_URL_SG = "https://auth.pingone.sg"
    PINGONE_AUTH_URL_ASIA = "https://auth.pingone.asia"
    _UNKNOWN = "__PINGONEAUTHURL_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "PingOneAuthUrl":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        pingone_auth_url_us: typing.Callable[[], T_Result],
        pingone_auth_url_ca: typing.Callable[[], T_Result],
        pingone_auth_url_eu: typing.Callable[[], T_Result],
        pingone_auth_url_au: typing.Callable[[], T_Result],
        pingone_auth_url_sg: typing.Callable[[], T_Result],
        pingone_auth_url_asia: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_US:
            return pingone_auth_url_us()
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_CA:
            return pingone_auth_url_ca()
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_EU:
            return pingone_auth_url_eu()
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_AU:
            return pingone_auth_url_au()
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_SG:
            return pingone_auth_url_sg()
        if self is PingOneAuthUrl.PINGONE_AUTH_URL_ASIA:
            return pingone_auth_url_asia()
        return _unknown_member(self._value_)
