# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.dnsactivity.classes.types.dns_activity import (
    DnsActivity as ocsf_v_1_3_0_dnsactivity_classes_types_dns_activity_DnsActivity,
)

DnsActivity = ocsf_v_1_3_0_dnsactivity_classes_types_dns_activity_DnsActivity
