# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations
from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import typing_extensions
from ...core.unchecked_base_model import UnionMetadata


class BridgeSelector_Id(UncheckedBaseModel):
    value: str
    type: typing.Literal["id"] = "id"

    class Config:
        smart_union = True


class BridgeSelector_Labels(UncheckedBaseModel):
    value: typing.List[str]
    type: typing.Literal["labels"] = "labels"

    class Config:
        smart_union = True


BridgeSelector = typing_extensions.Annotated[
    typing.Union[BridgeSelector_Id, BridgeSelector_Labels],
    UnionMetadata(discriminant="type"),
]
