# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import pydantic
from .upload_scan_status import UploadScanStatus
import typing
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class ScanStatus(UncheckedBaseModel):
    scan_id: str = pydantic.Field()
    """
    ID of the scan.
    """

    status: UploadScanStatus = pydantic.Field()
    """
    Specifies the status of the scan, which can be Complete, Pending, or Error.
    """

    message: typing.Optional[str] = pydantic.Field(default=None)
    """
    Provider specific status message for this scan.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
