# This file was auto-generated by Fern from our API Definition.

from ....v_1_3_0.cloudactivity.classes.types.cloud_activity import (
    CloudActivity as ocsf_v_1_3_0_cloudactivity_classes_types_cloud_activity_CloudActivity,
)

CloudActivity = ocsf_v_1_3_0_cloudactivity_classes_types_cloud_activity_CloudActivity
