# This file was auto-generated by Fern from our API Definition.

from ...ocsf.v_1_3_0.detectionfinding.classes.types.detection_finding import (
    DetectionFinding,
)

ThreatEvent = DetectionFinding
