# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .meta_api_primary_response import MetaApiPrimaryResponse
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class MetaApiResponse(UncheckedBaseModel):
    primary: typing.Optional[MetaApiPrimaryResponse] = None
    list_: typing.Optional[typing.Dict[str, typing.List[str]]] = pydantic.Field(
        alias="list", default=None
    )
    """
    All responses from backing API calls, indexed by endpoint URL.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
