# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .asset import Asset
import pydantic
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class UploadScanRequest(UncheckedBaseModel):
    assets: typing.List[Asset] = pydantic.Field()
    """
    Assets and optional findings to upload in the vulnerability scanning system.
    """

    source_name: typing.Optional[str] = pydantic.Field(default=None)
    """
    Name of the source for this scan, such as a tool or process. Does not have to be unique, defaults to `Integration import`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
