# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from ...common.types.id import Id
from ...core.pydantic_utilities import IS_PYDANTIC_V2


class IncidentResponseScheduleReference(UncheckedBaseModel):
    name: typing.Optional[str] = pydantic.Field(default=None)
    """
    The name of the incident response schedule being referenced.
    """

    desc: typing.Optional[str] = pydantic.Field(default=None)
    """
    The description of the incident response schedule being referenced.
    """

    uid: Id = pydantic.Field()
    """
    The unique identifier for the incident response schedule being referenced.
    """

    src_url: typing.Optional[str] = pydantic.Field(default=None)
    """
    A deep-linked url to the incident response schedule in a providers interface.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow"
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            smart_union = True
            extra = pydantic.Extra.allow
